<?php

namespace Drupal\o365_sso_user\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'o365_sso_user.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('o365_sso_user.settings');
    $form['use_graph_data'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use user data from Graph API'),
      '#description' => $this->t('When checked you can map field from the Graph API (/me endpoint) to field names in the user. These values get synced every login.'),
      '#default_value' => $config->get('use_graph_data'),
    ];

    $form['graph_data_mapping'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Field mapping Graph API > Drupal'),
      '#description' => $this->t('Add a field mapping per line. Use a pipe to separate the field name in Graph API and in Drupal. For instance "givenName|field_first_name".'),
      '#default_value' => $config->get('graph_data_mapping'),
      '#states' => [
        'visible' => [
          ':input[name="use_graph_data"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('o365_sso_user.settings')
      ->set('use_graph_data', $form_state->getValue('use_graph_data'))
      ->set('graph_data_mapping', $form_state->getValue('graph_data_mapping'))
      ->save();
  }

}
