<?php

namespace Drupal\o365\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\o365\O365ConnectorInterface;

/**
 * Defines the Office 365 connector entity.
 *
 * @ConfigEntityType(
 *   id = "o365_connector",
 *   label = @Translation("Office 365 connector"),
 *   handlers = {
 *     "list_builder" = "Drupal\o365\Controller\O365ConnectorListBuilder",
 *     "access" = "Drupal\o365\O365ConnectorAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\o365\Form\O365ConnectorForm",
 *       "edit" = "Drupal\o365\Form\O365ConnectorForm",
 *       "delete" = "Drupal\o365\Form\O365ConnectorDeleteForm"
 *     }
 *   },
 *   config_prefix = "o365_connector",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "status" = "status",
 *     "client_id" = "client_id",
 *     "client_secret" = "client_secret"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "status",
 *     "client_id",
 *     "client_secret",
 *     "tenant_id",
 *     "redirect_login",
 *     "auth_scopes",
 *   },
 *   links = {
 *     "edit-form" = "/admin/config/system/o365-connectors/{o365_connector}",
 *     "delete-form" = "/admin/config/system/o365-connectors/{o365_connector}/delete"
 *   }
 * )
 */
class O365Connector extends ConfigEntityBase implements O365ConnectorInterface {

  /**
   * The O365Connector ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The O365Connector label.
   *
   * @var string
   */
  protected $label;

  /**
   * The Microsoft client ID.
   *
   * @var string
   */
  protected $client_id;

  /**
   * The Microsoft client secret.
   *
   * @var string
   */
  protected $client_secret;

  /**
   * The Tenant identifier.
   *
   * @var string
   */
  protected $tenant_id;

  /**
   * The redirect URL string.
   *
   * @var string
   */
  protected $redirect_login;

  /**
   * The auth scopes.
   *
   * @var string
   */
  protected $auth_scopes;

  /**
   * {@inheritdoc}
   */
  public function getClientId(): string {
    return $this->client_id ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function getClientSecret(): string {
    return $this->client_secret ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function getTenantId(): string {
    return $this->tenant_id ?? 'common';
  }

  /**
   * {@inheritdoc}
   */
  public function getRedirectLogin(): string {
    return $this->redirect_login ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function getAuthScopes(): string {
    return $this->auth_scopes ?? '';
  }

}
