<?php

namespace Drupal\o365;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the Office 365 connector entity.
 *
 * @see \Drupal\o365\Entity\O365Connector.
 */
class O365ConnectorAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account): AccessResult {
    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'access o365 connectors');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit o365 connector');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete o365 connector');

      default:
        return AccessResult::allowedIfHasPermission($account, 'administer o365 connectors');
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'create o365 connector');
  }

}
