<?php

namespace Drupal\o365;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides as interface defining a SocialO365 entity.
 */
interface O365ConnectorInterface extends ConfigEntityInterface {

  /**
   * Gets the Microsoft client ID.
   *
   * @return string
   *   The Microsoft client ID.
   */
  public function getClientId(): string;

  /**
   * Gets the Microsoft client secret.
   *
   * @return string
   *   The Microsoft client secret.
   */
  public function getClientSecret(): string;

  /**
   * Gets the tenant identifier.
   *
   * @return string
   *   The tenant identifier.
   */
  public function getTenantId(): string;

  /**
   * Gets the redirect URL string.
   *
   * @return string
   *   The redirect URL string.
   */
  public function getRedirectLogin(): string;

  /**
   * Gets auth scopes.
   *
   * @return string
   *   The auth scopes.
   */
  public function getAuthScopes(): string;

}
